<!--
 * @Author: elkers
 * @Date: 2024-08-06 16:17:39
 * @LastEditors: hqs elkers@163.com
 * @LastEditTime: 2024-08-12 10:08:12
 * @FilePath: \water-qinghe-web\src\views\waterMeter\waterModel\index.vue
 * @Description: 水表型号
-->

<script setup>
import waterModelApi from "@/api/waterMeterApi/waterModel";
import setPostParams from "../../../utils/searchParams.js";

const {proxy} = getCurrentInstance();

/**
 * 搜索相关
 */
/** 搜索按钮操作 */
function handleQuery() {
    getList({keywords: queryParams.value.name})
}

/** 重置按钮操作 */
function resetQuery() {
    proxy.resetForm("queryRef");
    handleQuery();
}
/**
 *  Table表格权限数据列表相关
 */

const pageParam = ref({
    total: 0,
    limit: 0,
    page: 1,
})
const tableData = ref([]);
let tableHeader = ref({

    model: "水表型号",
    type: "水表类型",
    standard: "水表规格",
    comMode: "通讯方式",
    comProtocolName: "通讯协议",
    material: "水表材质",
    factory: "生产厂家",
    status: '状态'

})

/** 获取列表 */
async function getList(val) {
    loading.value = true;
    let postParam = setPostParams(val)
    await waterModelApi().search(postParam).then((res) => {
        tableData.value = res.data.list
        pageParam.value.total = res.data.total
        pageParam.value.limit = res.data.limit
        pageParam.value.page = res.data.page
    })
    loading.value = false;
}

/** 新增按钮操作 */
async function handleAdd() {
    reset();
    open.value = true;
    title.value = "新增用户";
}

/** 修改按钮操作 */
async function handleUpdate(row) {
    reset();
    // form.value = Object.assign({},row)
    Object.keys(row).forEach(key => {
        if (form.value.hasOwnProperty(key)) {
            form.value[key] = row[key];
        }
    });
    form.value.id = row.id
    open.value = true;
    title.value = "修改";
}

/** 删除按钮操作 */
function handleDelete(row) {
    proxy.$modal.confirm('是否确认删除名称为"' + row.contact + '"的数据项?').then(function () {
        return waterModelApi().remove(row.id);
    }).then(() => {
        getList();
        proxy.$modal.msgSuccess("删除成功");
    }).catch(() => {
    });
}


/**
 *  新增/修改弹窗Form表单相关
 */
const open = ref(false);
const loading = ref(false);
const title = ref("");
formLabelWidth: 200;
const data = reactive({

    form: {},
    queryParams: {
        name: undefined,
    },
    rules: {
        model: [
            {required: true, message: '请输入水表型号', trigger: 'blur'},
            {max: 50, message: '长度不超过50', trigger: 'blur'},
            {pattern: '^[a-zA-Z0-9_-]+$', message: '请输入数字、字母或下划线、短横线', trigger: 'blur'},
        ],
        type: [
            {required: true, message: '请选择水表类型', trigger: 'change'}
        ],
        standard: [
            {required: true, message: '请选择水表规格', trigger: 'change'}
        ],
        comMode: [
            {required: true, message: '请选择通讯方式', trigger: 'change'}
        ],
        comProtocolId: [
            {required: true, message: '请选择通讯协议', trigger: 'change'}
        ],
        material: [
            {required: true, message: '请选择水表材质', trigger: 'change'}
        ],
        accuracy: [
            {required: true, message: '请输入水表精度', trigger: 'blur'},
            {
                pattern: '^(?!100$)(\\d{1,2}(?:\\.\\d{1,2})?|0(?:\\.\\d{1,2})?)$',
                message: '请输入小于100的整数或小数（小数点后保留两位）',
                trigger: 'blur'
            },
        ],
        factory: [
            {max: 50, message: '长度不超过50', trigger: 'blur'}
        ],
        comment: [
            {max: 500, message: '长度不超过500', trigger: 'blur'}
        ],
    },
});
const {queryParams, form, rules} = toRefs(data);
const type = ref([
    {name: '智能水表'},
    {name: '机械师水表'},
    {name: '预付费水表'},
    {name: '远传水表'},
    {name: '其他'},
])
const standard = ref([
    {name: 'DN15'},
    {name: 'DN20'},
    {name: 'DN25'},
    {name: 'DN32'},
    {name: 'DN40'},
    {name: 'DN50'},
])
const mode = ref([
    {name: '蓝牙'},
    {name: 'NB-loT'},
    {name: 'LoRa'},
    {name: '其他'},
])
const protocol = ref([
    {id: 1, name: 'modbus-RTU'},
    {id: 2, name: 'modbus-1'},
    {id: 3, name: 'modbus-2'},
])
const material = ref([
    {name: '铜'},
    {name: '铁'},
    {name: '不锈钢'},
    {name: '塑料'},
    {name: '其他'},
])
//上传文件，添加图片地址信息
const uploadData = (data) => {
    form.value.headImg = data.newFileView
}

/** 提交按钮 */
function submitForm() {
    proxy.$refs["userRef"].validate(valid => {
        if (valid) {
            form.value.contactPhone = Number(form.value.contactPhone)
            if (form.value.id != undefined) {
                waterModelApi().modify(form.value).then(res => {
                    proxy.$modal.msgSuccess("修改成功");
                    open.value = false;
                    getList();
                }).catch(() => {
                    open.value = false;
                    proxy.$modal.msgError("修改失败");
                });
            } else {
                waterModelApi().create(form.value).then(res => {
                    proxy.$modal.msgSuccess("新增成功");
                    open.value = false;
                    getList();
                }).catch(() => {
                    open.value = false;
                    proxy.$modal.msgError("新增失败");
                });
                ;
            }
        }
    });
}

/** 取消按钮 */
function cancel() {
    open.value = false;
    reset();
}

/** 表单重置 */
function reset() {
    form.value = {
        name: '',
        contact: '',
        headImg: '',
        contactPhone: undefined,
        contact: '',
        email: '',
    };
    proxy.resetForm("userRef");
}

getList();
</script>
<template>
    <div class="app-container">
        <el-form :model="queryParams" ref="queryRef" :inline="true">
            <el-form-item label="水表型号" prop="model">
                <el-input
                        v-model="queryParams.name"
                        placeholder="请输入水表型号"
                        clearable
                        style="width: 200px"
                        @keyup.enter="handleQuery"
                />
            </el-form-item>
            <el-form-item>
                <el-button type="primary" icon="Search" @click="handleQuery">搜索</el-button>
                <el-button icon="Refresh" @click="resetQuery">重置</el-button>
            </el-form-item>
        </el-form>

        <el-row :gutter="10" class="mb8">
            <el-col :span="1.5">
                <el-button
                        type="primary"
                        plain
                        icon="Plus"
                        @click="handleAdd"
                >新增
                </el-button>
            </el-col>
        </el-row>
        <!--表格及分页-->
        <el-table v-loading="loading" :data="tableData">
            <el-table-column
                    v-for="(item, key, index) of tableHeader"
                    :prop="key.toString()"
                    :label="item"
                    :key="index"
                    align="center"
            >
                <template #default="scope">
                    <div v-if="key.toString() == 'headImg'">
                        <img :src="scope.row.headImg" class="table-headImg"/>
                    </div>
                </template>
            </el-table-column>
            <el-table-column label="操作" width="180" align="center" class-name="small-padding fixed-width">
                <template #default="scope">
                    <el-button link type="primary" icon="Edit" v-has="['update',route]"
                               @click="handleUpdate(scope.row)">修改
                    </el-button>
                    <el-button link type="primary" icon="Delete" v-has="['delete',route]"
                               @click="handleDelete(scope.row)">删除
                    </el-button>
                </template>
            </el-table-column>
        </el-table>
        <pagination
                :total="pageParam.total"
                v-model:page="pageParam.page"
                v-model:limit="pageParam.limit"
                :page-sizes="[10,20,30]"
                @pagination="getList"
        />
        <!-- 添加或修改对话框 -->
        <el-dialog :title="title" v-model="open" append-to-body center>
            <el-form class="form-box" ref="userRef" :model="form" :rules="rules" label-width='auto'>
                        <el-form-item label="水表型号" prop="model">
                            <el-input v-model="form.name" placeholder="请输入水表型号"/>
                        </el-form-item>
                        <el-form-item label="水表类型" prop="type">
                            <el-select v-model="form.type" :label-width="formLabelWidth" placeholder="请选择水表类型"
                                       size="large">
                                <el-option
                                        v-for="item in type"
                                        :key="item.name"
                                        :label="item.name"
                                        :title="item.name"
                                        :value="item.name"
                                />
                            </el-select>
                        </el-form-item>
                        <el-form-item label="水表规格" prop="standard">
                            <el-select v-model="form.standard" class="m-2" placeholder="请选择水表规格" size="large">
                                <el-option
                                        v-for="item in standard"
                                        :key="item.name"
                                        :label="item.name"
                                        :title="item.name"
                                        :value="item.name"
                                />
                            </el-select>
                        </el-form-item>
                        <el-form-item label="通讯方式" prop="comMode">
                            <el-select v-model="form.comMode" class="m-2" placeholder="请选择通讯方式" size="large">
                                <el-option
                                        v-for="item in mode"
                                        :key="item.name"
                                        :label="item.name"
                                        :title="item.name"
                                        :value="item.name"
                                />
                            </el-select>
                        </el-form-item>
                        <el-form-item label="通讯协议" prop="comProtocolId">
                            <el-select v-model="form.comProtocolId" class="m-2" placeholder="请选择通讯协议"
                                       size="large">
                                <el-option
                                        v-for="item in protocol"
                                        :key="item.id"
                                        :label="item.name"
                                        :title="item.name"
                                        :value="item.id"
                                />
                            </el-select>
                        </el-form-item>
                        <el-form-item label="水表材质" prop="material">
                            <el-select v-model="form.material" class="m-2" placeholder="请选择水表材质" size="large">
                                <el-option
                                        v-for="item in material"
                                        :key="item.name"
                                        :label="item.name"
                                        :title="item.name"
                                        :value="item.name"
                                />
                            </el-select>
                        </el-form-item>
                        <el-form-item label="生产厂家" prop="material">
                            <el-select v-model="form.material" class="m-2" placeholder="请选择生产厂家" size="large">
                                <el-option
                                        v-for="item in material"
                                        :key="item.name"
                                        :label="item.name"
                                        :title="item.name"
                                        :value="item.name"
                                />
                            </el-select>
                        </el-form-item>
                    <el-form-item label="备注" prop="comment">
                        <el-input v-model="form.comment" autocomplete="off" placeholder="请输入备注"></el-input>
                    </el-form-item>
            </el-form>
            <template #footer>
                <div class="dialog-footer">
                    <el-button type="primary" @click="submitForm">确 定</el-button>
                    <el-button @click="cancel">取 消</el-button>
                </div>
            </template>
        </el-dialog>
    </div>
</template>

<style>
.table-headImg{
    width: 50px;
    height: 50px;
}
</style>
 